@@ -77,7 +77,7 @@ class WindowContextMenu extends PopupMenu.PopupMenu {
             'notify::minimized', this._updateMinimizeItem.bind(this),
             'notify::maximized-horizontally', this._updateMaximizeItem.bind(this),
             'notify::maximized-vertically', this._updateMaximizeItem.bind(this),
-            this);
+            this.actor);
 
         this._updateMinimizeItem();
         this._updateMaximizeItem();
@@ -125,10 +125,6 @@ class WindowTitle extends St.BoxLayout {
         this.label_actor.clutter_text.single_line_mode = true;
         this.add_child(this.label_actor);
 
-        this._textureCache = St.TextureCache.get_default();
-        this._textureCache.connectObject('icon-theme-changed',
-            () => this._updateIcon(), this);
-
         this._metaWindow.connectObject(
             'notify::wm-class',
             () => this._updateIcon(), GObject.ConnectFlags.AFTER,
@@ -176,7 +172,7 @@ class BaseButton extends DashItemContainer {
             GTypeFlags: GObject.TypeFlags.ABSTRACT,
             Properties: {
                 'ignore-workspace': GObject.ParamSpec.boolean(
-                    'ignore-workspace', 'ignore-workspace', 'ignore-workspace',
+                    'ignore-workspace', null, null,
                     GObject.ParamFlags.READWRITE,
                     false),
             },
@@ -227,7 +223,7 @@ class BaseButton extends DashItemContainer {
     }
 
     get active() {
-        return this.has_style_class_name('focused');
+        return this._button.has_style_class_name('focused');
     }
 
     // eslint-disable-next-line camelcase
@@ -453,9 +449,9 @@ class WindowButton extends BaseButton {
         super._updateStyle();
 
         if (this.metaWindow.minimized)
-            this.add_style_class_name('minimized');
+            this._button.add_style_class_name('minimized');
         else
-            this.remove_style_class_name('minimized');
+            this._button.remove_style_class_name('minimized');
     }
 
     _windowEnteredOrLeftMonitor(metaDisplay, monitorIndex, metaWindow) {
@@ -591,11 +587,6 @@ class AppButton extends BaseButton {
         this._appContextMenu.actor.hide();
         Main.uiGroup.add_child(this._appContextMenu.actor);
 
-        this._textureCache = St.TextureCache.get_default();
-        this._textureCache.connectObject('icon-theme-changed', () => {
-            this._icon.child = app.create_icon_texture(ICON_TEXTURE_SIZE);
-        }, this);
-
         this.app.connectObject('windows-changed',
             () => this._windowsChanged(), this);
         this._windowsChanged();
@@ -781,10 +772,11 @@ class WindowList extends St.Widget {
             () => this._onWorkspaceMenuSet(), this);
         this._onWorkspaceMenuSet();
 
-        Main.layoutManager.addChrome(this, {
+        const chromeOptions = {
             affectsStruts: true,
             trackFullscreen: true,
-        });
+        };
+        Main.layoutManager.addChrome(this, chromeOptions);
         Main.uiGroup.set_child_above_sibling(this, Main.layoutManager.panelBox);
         Main.ctrlAltTabManager.addGroup(this, _('Window List'), 'start-here-symbolic');
 
@@ -821,10 +813,12 @@ class WindowList extends St.Widget {
 
         Main.overview.connectObject(
             'showing', () => {
+                Main.layoutManager.untrackChrome(this);
                 this.hide();
                 this._updateKeyboardAnchor();
             },
             'hidden', () => {
+                Main.layoutManager.trackChrome(this, chromeOptions);
                 this.visible = !this._monitor.inFullscreen;
                 this._updateKeyboardAnchor();
             }, this);
